package com.polarsparc.android.droiddailytodo;

import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ImageButton;
import android.widget.ListView;
import android.util.Log;

public class MainDailyTodoActivity extends Activity {
	
	private static String TAG = "MainDailyTodoActivity";
	
	final int TODO_PREFERENCE = 1;
	final int CREATE_TODO = 2;
	
	private PreferenceState state;
	
	private TodoTaskManager manager;
	
	private TodoDatabaseManager database;
	
	private ArrayAdapter<TodoTask> adapter;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_daily_todo);
		
		state = new PreferenceState();
		
		final String deleteKey = getResources().getString(R.string.pref_delete_key);
		final String themeKey = getResources().getString(R.string.pref_theme_key);
		
		Log.i(TAG, "MainDailyTodoActivity - onCreate(): deleteKey = " + deleteKey);
		Log.i(TAG, "MainDailyTodoActivity - onCreate(): themeKey = " + themeKey);
		
		SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(this);
		
		state.setAlertFlag(preferences.getBoolean(deleteKey, false));
		state.setThemeIndex(Integer.valueOf(preferences.getString(themeKey, "0")));
		
		Log.i(TAG, "MainDailyTodoActivity - onCreate(): alertFlag = " + state.isAlertFlag());
		Log.i(TAG, "MainDailyTodoActivity - onCreate(): themeIndex = " + state.getThemeIndex());
		
		manager = new TodoTaskManager();
		
		database = new TodoDatabaseManager(this);
		
		manager.addAllTodoTasks(database.fetchAllTodoEntries());
		
		adapter = new TodoTaskListAdapter(this, state, manager, database);
		
		final ImageButton imagebutton = (ImageButton) findViewById(R.id.add_todo);
		imagebutton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				String action = getResources().getString(R.string.action_name);
				
				Intent intent = new Intent(action);
				
				startActivityForResult(intent, CREATE_TODO);
			}
		});
		
		final ListView listview = (ListView) findViewById(R.id.list);
		listview.setAdapter(adapter);
	}
    
    /*
     * Callback method when create todo activity returns a result
     */
    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
    	if (requestCode == TODO_PREFERENCE) {
    		final String deleteKey = getResources().getString(R.string.pref_delete_key);
    		final String themeKey = getResources().getString(R.string.pref_theme_key);
    		
    		SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(this);
    		
    		state.setAlertFlag(preferences.getBoolean(deleteKey, false));
    		state.setThemeIndex(Integer.valueOf(preferences.getString(themeKey, "0")));
    		
    		Log.i(TAG, "MainDailyTodoActivity - onActivityResult(): alertFlag = " + state.isAlertFlag());
    		Log.i(TAG, "MainDailyTodoActivity - onActivityResult(): themeIndex = " + state.getThemeIndex());
    		
    		adapter.notifyDataSetChanged();
    	}
    	else if (requestCode == CREATE_TODO && resultCode == Activity.RESULT_OK) {
    		int hour = data.getIntExtra("pickedHour", -1);
    		int minute = data.getIntExtra("pickedMinute", -1);
    		
    		String title = data.getStringExtra("todoTitle");
    		
    		Log.i(TAG, "MainDailyTodoActivity - onActivityResult(): hour = " + hour);
    		Log.i(TAG, "MainDailyTodoActivity - onActivityResult(): minute = " + minute);
    		Log.i(TAG, "MainDailyTodoActivity - onActivityResult(): title = " + title);
    		
    		if (hour >= 0 && minute >= 0 && title != null && title.isEmpty() == false) {
    			TodoTask entry = manager.addTodoTask(title, hour, minute);
    			if (entry != null) {
    				database.insertTodoEntry(entry);
    				adapter.notifyDataSetChanged();
    			}
    		}
    	}
    }

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.todo_list, menu);
		
		return true;
	}
	
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
    	switch (item.getItemId()) {
    		case R.id.action_settings:
    		{
    			Intent intent = new Intent(this, DailyTodoPreferences.class);
    			
    			startActivityForResult(intent, TODO_PREFERENCE);
    			
    			return true;
    		}
    			
    		case R.id.action_about:
    		{
    			LayoutInflater inflater = LayoutInflater.from(this);
    			
    			View view = inflater.inflate(R.layout.dialog_about, null);
    			
    			AlertDialog alert = new AlertDialog.Builder(this).create();
    			alert.setView(view);
    			alert.setButton("OK", new DialogInterface.OnClickListener() {
    				public void onClick(DialogInterface dialog, int which) {
    					// Do nothing
    				}
    			});
    			alert.show();
    			
    			return true;
    		}
        }
    	
        return false;
    }
}
