package com.polarsparc.android.droiddailytodo;

import java.util.List;
import java.util.ArrayList;

import android.content.Context;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class TodoDatabaseManager extends SQLiteOpenHelper {

	private static String TAG = "TodoDatabaseManager";
	
    private static final int DATABASE_VERSION = 1;
    
    private static final String DATABASE_NAME = "TodoTasks.db";
 
    private static final String TODO_TASKS_TABLE = "todo_tasks";
 
    private static final String TODO_ID = "id";
    private static final String TODO_TITLE = "title";
    private static final String TODO_DUE_HOUR = "due_hour";
    private static final String TODO_DUE_MINUTE = "due_minute";
    
    private static final String CREATE_TODO_TABLE = "CREATE TABLE " +
    		TODO_TASKS_TABLE + "(" +
           	TODO_ID + " INTEGER PRIMARY KEY," +
           	TODO_TITLE + " TEXT," +
           	TODO_DUE_HOUR + " INTEGER, " +
           	TODO_DUE_MINUTE + " INTEGER" +
        ")";
    
    private static final String DROP_TODO_TABLE = "DROP TABLE IF EXISTS " +
    	TODO_TASKS_TABLE;
    
    private static final String QUERY_TODO_TABLE = "SELECT * FROM " +
    	TODO_TASKS_TABLE;
	
	public TodoDatabaseManager(Context context) {
		super(context, DATABASE_NAME, null, DATABASE_VERSION);
	}

	@Override
    public void onCreate(SQLiteDatabase db) {
		db.execSQL(CREATE_TODO_TABLE);
	}
	
	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		db.execSQL(DROP_TODO_TABLE);
		onCreate(db);
	}
	
	public boolean insertTodoEntry(TodoTask entry) {
		SQLiteDatabase db = this.getWritableDatabase();
		
		ContentValues record = new ContentValues();
		record.put(TODO_TITLE, entry.getTitle());
		record.put(TODO_DUE_HOUR, entry.getHour());
		record.put(TODO_DUE_MINUTE, entry.getMinute());
		
		long id = -1;
		if ((id = db.insert(TODO_TASKS_TABLE, null, record)) > 0) {
			db.close();
			
			entry.setId(id);
			
			Log.i(TAG, "insertTodoEntry(): Successfully added entry for " + entry.getTitle() + " <" + entry.getId() + ">");
			
			return true;
		}
		
		return false;
	}
	
	public void deleteTodoEntry(TodoTask entry) {
		SQLiteDatabase db = this.getWritableDatabase();
		
	    db.delete(TODO_TASKS_TABLE, TODO_ID + " = ?",
	    	new String[] { String.valueOf(entry.getId()) });
	    db.close();
	    
	    Log.i(TAG, "deleteTodoEntry(): Successfully deleted entry for " + entry.getTitle() + " <" + entry.getId() + ">");
	}
	
	public List<TodoTask> fetchAllTodoEntries() {
		List<TodoTask> list = new ArrayList<TodoTask>();
		
        SQLiteDatabase db = this.getWritableDatabase();
        
        Cursor cursor = db.rawQuery(QUERY_TODO_TABLE, null);
 
        if (cursor.moveToFirst()) {
            do {
            	TodoTask entry = new TodoTask();
            	
            	entry.setId(cursor.getLong(0));
            	entry.setTitle(cursor.getString(1));
            	entry.setHour(cursor.getInt(2));
            	entry.setMinute(cursor.getInt(3));
                
                list.add(entry);
                
            } while (cursor.moveToNext());
        }
        
        cursor.close();
        
        db.close();
        
        Log.i(TAG, "fetchAllTodoEntries(): List size: " + list.size());
        
        return list;
	}
	
}
