package com.polarsparc.android.droiddailytodo;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.View;
import android.view.ViewGroup;
import android.view.LayoutInflater;
import android.widget.ArrayAdapter;
import android.widget.CheckBox;
import android.widget.TextView;
import android.widget.Toast;

public class TodoTaskListAdapter extends ArrayAdapter<TodoTask> {
	
	private String format = "Due @ %02d:%02d";
	
	private Context context;
	
	private PreferenceState state;
	
	private TodoTaskManager manager;
	
	private TodoDatabaseManager database;
	
	public TodoTaskListAdapter(Context context, PreferenceState state, TodoTaskManager manager, TodoDatabaseManager database) {
		super(context, R.layout.todo_list_item, manager.getTodoTaskList());
		this.context = context;
		this.state = state;
		this.manager = manager;
		this.database = database;
	}
	
	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		if (convertView == null) {
			LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		
			convertView = inflater.inflate(R.layout.todo_list_item, parent, false);
		}
		
		switch (state.getThemeIndex()) {
			case 1:
				convertView.setBackgroundResource(R.drawable.custom_blue_shape);
				break;
			case 2:
				convertView.setBackgroundResource(R.drawable.custom_brown_shape);
				break;
			case 3:
				convertView.setBackgroundResource(R.drawable.custom_green_shape);
				break;
		}
		
		final int index = position;
		
		final TodoTask task = manager.getTodoTask(index);
		
		final String title = task.getTitle();
		final String time = String.format(format, task.getHour(), task.getMinute());
		
		// Title
		TextView todoTitle = (TextView) convertView.findViewById(R.id.title);
		todoTitle.setText(title);
		todoTitle.requestLayout(); // Very important
		
		// Due Time
		TextView dueTime = (TextView) convertView.findViewById(R.id.due_time);
		dueTime.setText(time);
		dueTime.requestLayout(); // Very important
		
		// Completed
		CheckBox completed = (CheckBox) convertView.findViewById(R.id.completed);
		completed.setChecked(false);
		completed.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				if (((CheckBox)view).isChecked()) {
					if (state.isAlertFlag()) {
						AlertDialog alert = new AlertDialog.Builder(context).create();
						alert.setMessage("Completed To Do Task - " + title);
		    			alert.setButton("OK", new DialogInterface.OnClickListener() {
		    				public void onClick(DialogInterface dialog, int which) {
		    					TodoTask entry = manager.removeTodoTask(index);
		    					database.deleteTodoEntry(entry);
				    			notifyDataSetChanged();
		    				}
		    			});
		    			alert.show();
					}
					else {
						TodoTask entry = manager.removeTodoTask(index);
						database.deleteTodoEntry(entry);
						notifyDataSetChanged();
						Toast.makeText(context, "Completed To Do Task - " + title, Toast.LENGTH_LONG).show();
					}
				}
			}
		});
		
		return convertView;
	}
	
}
